@@ -8,7 +8,6 @@
 
 #include "mainwindow.h"
 #include "krdc_debug.h"
-#include "remoteview.h"
 #include "settings.h"
 #include "config/preferencesdialog.h"
 #include "floatingtoolbar.h"
@@ -36,6 +35,7 @@
 #include <QDockWidget>
 #include <QFontMetrics>
 #include <QGroupBox>
+#include <QGuiApplication>
 #include <QHBoxLayout>
 #include <QHeaderView>
 #include <QIcon>
@@ -45,7 +45,6 @@
 #include <QMenu>
 #include <QMenuBar>
 #include <QPushButton>
-#include <QScrollArea>
 #include <QSortFilterProxyModel>
 #include <QStatusBar>
 #include <QScrollBar>
@@ -54,6 +53,7 @@
 #include <QTimer>
 #include <QToolBar>
 #include <QVBoxLayout>
+#include <QRegularExpression>
 
 MainWindow::MainWindow(QWidget *parent)
         : KXmlGuiWindow(parent),
@@ -204,7 +204,7 @@ void MainWindow::loadAllPlugins()
 
             if (result) {
                 RemoteViewFactory *component = result.plugin;
-                const int sorting = plugin.value(QStringLiteral("X-KDE-KRDC-Sorting")).toInt();
+                const int sorting = plugin.value(QStringLiteral("X-KDE-KRDC-Sorting"), 0);
                 m_remoteViewFactories.insert(sorting, component);
             }
         }
@@ -225,7 +225,8 @@ QUrl MainWindow::getInputUrl()
     QString userInput = m_addressInput->text();
     qCDebug(KRDC) << "input url " << userInput;
     // percent encode usernames so QUrl can parse it
-    int lastAtIndex = userInput.indexOf(QRegExp(QStringLiteral("@[^@]+$")));
+    static QRegularExpression reg(QStringLiteral("@[^@]+$"));
+    int lastAtIndex = userInput.indexOf(reg);
     if (lastAtIndex >0) {
         userInput = QString::fromLatin1(QUrl::toPercentEncoding(userInput.left(lastAtIndex))) + userInput.mid(lastAtIndex);
         qCDebug(KRDC) << "input url " << userInput;
@@ -288,7 +289,6 @@ void MainWindow::newConnection(const QUrl &newUrl, bool switchFullscreenWhenConn
     connect(view, SIGNAL(statusChanged(RemoteView::RemoteStatus)), this, SLOT(statusChanged(RemoteView::RemoteStatus)));
     connect(view, SIGNAL(disconnected()), this, SLOT(disconnectHost()));
 
-    view->winId();  // native widget workaround for bug 253365
     QScrollArea *scrollArea = createScrollArea(m_tabWidget, view);
 
     const int indexOfNewConnectionWidget = m_tabWidget->indexOf(m_newConnectionWidget);
@@ -349,11 +349,10 @@ void MainWindow::resizeTabWidget(int w, int h)
     }
 
     const QSize viewSize = QSize(w,h);
-    QDesktopWidget *desktop = QApplication::desktop();
+    QScreen *currentScreen = QGuiApplication::screenAt(geometry().center());
 
     if (Settings::fullscreenOnConnect()) {
-        int currentScreen = desktop->screenNumber(this);
-        const QSize screenSize = desktop->screenGeometry(currentScreen).size();
+        const QSize screenSize = currentScreen->availableGeometry().size();
 
         if (screenSize == viewSize) {
             qCDebug(KRDC) << "screen size equal to target view size -> switch to fullscreen mode";
@@ -366,7 +365,7 @@ void MainWindow::resizeTabWidget(int w, int h)
         QWidget* currentWidget = m_tabWidget->currentWidget();
         const QSize newWindowSize = size() - currentWidget->frameSize() + viewSize;
 
-        const QSize desktopSize = desktop->availableGeometry().size();
+        const QSize desktopSize = currentScreen->availableGeometry().size();
         qCDebug(KRDC) << "new window size: " << newWindowSize << " available space:" << desktopSize;
 
         if ((newWindowSize.width() >= desktopSize.width()) || (newWindowSize.height() >= desktopSize.height())) {
@@ -502,7 +501,6 @@ void MainWindow::switchFullscreen()
         KToggleFullScreenAction::setFullScreen(m_fullscreenWindow, true);
 
         MinimizePixel *minimizePixel = new MinimizePixel(m_fullscreenWindow);
-        minimizePixel->winId(); // force it to be a native widget (prevents problem with QX11EmbedContainer)
         connect(minimizePixel, SIGNAL(rightClicked()), m_fullscreenWindow, SLOT(showMinimized()));
         m_fullscreenWindow->installEventFilter(this);
 
@@ -802,7 +800,6 @@ void MainWindow::showRemoteViewToolbar()
 
     if (!m_toolBar) {
         m_toolBar = new FloatingToolBar(m_fullscreenWindow, m_fullscreenWindow);
-        m_toolBar->winId(); // force it to be a native widget (prevents problem with QX11EmbedContainer)
         m_toolBar->setSide(FloatingToolBar::Top);
 
         KComboBox *sessionComboBox = new KComboBox(m_toolBar);
